@@ -35,25 +35,12 @@ do_call <- function(f, ..., .args = list(), .env = parent.frame()) {
 }
 
 add_class <- function(x, class) {
-  if (!is(x, class)) {
-    class(x) <- c(class, class(x))
+  if (!inherits(x, class)) {
+    class(x) <- c(class(x), class)
   }
   x
 }
 
-`%||%` <- function(lhs, rhs) {
-  lres <- withVisible(eval(lhs, envir = parent.frame()))
-  if (is.null(lres$value)) {
-    eval(rhs, envir = parent.frame())
-  } else {
-    if (lres$visible) {
-      lres$value
-    } else {
-      invisible(lres$value)
-    }
-  }
-}
-
 `%&&%` <- function(lhs, rhs) {
   lres <- withVisible(eval(lhs, envir = parent.frame()))
   if (!is.null(lres$value)) {
