@@ -4,9 +4,9 @@
 test_that("sample_correlated_gnp works", {
   withr::local_seed(42)
 
-  g <- erdos.renyi.game(10, .1)
+  g <- sample_gnp(10, .1)
   g2 <- sample_correlated_gnp(g, corr = 1, p = g$p, permutation = NULL)
-  expect_that(g[], equals(g2[]))
+  expect_equal(g[], g2[])
 
   g3 <- sample_correlated_gnp(g, corr = 0, p = g$p, permutation = NULL)
   c3 <- cor(as.vector(g[]), as.vector(g3[]))
@@ -16,9 +16,9 @@ test_that("sample_correlated_gnp works", {
 test_that("sample_correlated_gnp works when p is not given", {
   withr::local_seed(42)
 
-  g <- erdos.renyi.game(10, .1)
+  g <- sample_gnp(10, .1)
   g2 <- sample_correlated_gnp(g, corr = 1)
-  expect_that(g[], equals(g2[]))
+  expect_equal(g[], g2[])
 
   g3 <- sample_correlated_gnp(g, corr = 0)
   c3 <- cor(as.vector(g[]), as.vector(g3[]))
@@ -30,7 +30,7 @@ test_that("sample_correlated_gnp works even for non-ER graphs", {
 
   g <- sample_grg(100, 0.2)
   g2 <- sample_correlated_gnp(g, corr = 1)
-  expect_that(g[], equals(g2[]))
+  expect_equal(g[], g2[])
 
   g3 <- sample_correlated_gnp(g, corr = 0)
   c3 <- cor(as.vector(g[]), as.vector(g3[]))
@@ -54,35 +54,35 @@ test_that("sample_correlated_gnp corner cases work", {
     graph.isomorphic(g, g2)
   }
 
-  g <- erdos.renyi.game(10, .3)
+  g <- sample_gnp(10, .3)
   g2 <- sample_correlated_gnp(g, corr = 0.000001, p = .99999999)
   expect_true(is.full(g2))
 
   g3 <- sample_correlated_gnp(g, corr = 0.000001, p = 0.0000001)
-  expect_that(ecount(g3), equals(0))
-  expect_that(vcount(g3), equals(10))
+  expect_equal(ecount(g3), 0)
+  expect_equal(vcount(g3), 10)
 
-  gg <- erdos.renyi.game(10, .3, directed = TRUE)
+  gg <- sample_gnp(10, .3, directed = TRUE)
   gg2 <- sample_correlated_gnp(gg, corr = 0.000001, p = .99999999)
   expect_true(is.full(gg2))
 
   gg3 <- sample_correlated_gnp(gg, corr = 0.000001, p = 0.0000001)
-  expect_that(ecount(gg3), equals(0))
-  expect_that(vcount(gg3), equals(10))
+  expect_equal(ecount(gg3), 0)
+  expect_equal(vcount(gg3), 10)
 })
 
 test_that("permutation works for sample_correlated_gnp", {
   withr::local_seed(42)
 
-  g <- erdos.renyi.game(10, .3)
+  g <- sample_gnp(10, .3)
   perm <- sample(vcount(g))
   g2 <- sample_correlated_gnp(g, corr = .99999, p = .3, permutation = perm)
   g <- permute(g, perm)
-  expect_that(g[], equals(g2[]))
+  expect_equal(g[], g2[])
 
-  g <- erdos.renyi.game(10, .3)
+  g <- sample_gnp(10, .3)
   perm <- sample(vcount(g))
   g2 <- sample_correlated_gnp(g, corr = 1, p = .3, permutation = perm)
   g <- permute(g, perm)
-  expect_that(g[], equals(g2[]))
+  expect_equal(g[], g2[])
 })
