@@ -8,8 +8,8 @@ test_that("graphNEL conversion works", {
   g2 <- graph_from_graphnel(N)
   gi <- graph.isomorphic.vf2(g, g2)
   expect_true(gi$iso)
-  expect_that(gi$map12, equals(1:vcount(g)))
-  expect_that(gi$map21, equals(1:vcount(g)))
+  expect_equal(gi$map12, 1:vcount(g))
+  expect_equal(gi$map21, 1:vcount(g))
 
   ## Attributes
 
@@ -19,13 +19,13 @@ test_that("graphNEL conversion works", {
 
   N <- as_graphnel(g)
   g2 <- graph_from_graphnel(N)
-  expect_true(graph.isomorphic(g, g2))
-  expect_that(V(g)$name, equals(V(g2)$name))
+  expect_isomorphic(g, g2)
+  expect_equal(V(g)$name, V(g2)$name)
 
-  A <- as_adj(g, attr = "weight", sparse = FALSE)
-  A2 <- as_adj(g2, attr = "weight", sparse = FALSE)
-  expect_that(A, equals(A))
-  expect_that(g$name, equals(g2$name))
+  A <- as_adjacency_matrix(g, attr = "weight", sparse = FALSE)
+  A2 <- as_adjacency_matrix(g2, attr = "weight", sparse = FALSE)
+  expect_equal(A, A)
+  expect_equal(g$name, g2$name)
 })
 
 test_that("graphNEL does not duplicate loop edges", {
@@ -37,5 +37,5 @@ test_that("graphNEL does not duplicate loop edges", {
   igr <- graph_from_adjacency_matrix(mat, mode = "undirected", weighted = T)
 
   grNEL <- as_graphnel(igr)
-  expect_that(graph::edgeL(grNEL)$A$edges, equals(c(1, 2)))
+  expect_equal(graph::edgeL(grNEL)$A$edges, c(1, 2))
 })
